<#
	.SYNOPSIS
		Start-ISsisService
	.DESCRIPTION
		Start SQL Server Integration Server service
	.PARAMETER serverInstance
		SQL Server Instance
	.EXAMPLE
		.\Start-ISsisService -serverInstance server01\sql2012
	.INPUTS
	.OUTPUTS
	.NOTES
	.LINK
#>

param (
	[string]$serverInstance = "$(Read-Host 'Server Instance' [e.g. server01\sql2012])"
)

begin {
	[void][reflection.assembly]::LoadWithPartialName("Microsoft.SqlServer.Smo")
}
process {
	try {
		Write-Verbose "Start SQL Server Integration Server service..."

		$smoServer = new-object Microsoft.SqlServer.Management.Smo.Server $serverInstance
		$ver = $smoServer.Information.VersionMajor 

		$isSQLSupported = $false
		if ($ver -eq 9) {
			$service = 'MsDtsServer'
			$isSQLSupported = $true
		} elseif ($ver -eq 10) {
			$service = 'MsDtsServer100'
			$isSQLSupported = $true
		} elseif ($ver -eq 11) {
			$service = 'SQL Server Integration Services 11.0'
			$isSQLSupported = $true
		}

		if ($isSQLSupported) {
			Start-Service $service
			Write-Output "$service service started"
		} else {
			Write-Output "SQL Server version not supported"
		}
	} 
	catch [Exception] {
		Write-Error $Error[0]
		$err = $_.Exception
		while ( $err.InnerException ) {
			$err = $err.InnerException
			Write-Output $err.Message
		}
	}
}